git: f3229b62a149 - main - LinuxKPI: 802.11 handle connection loss differently

From: Bjoern A. Zeeb <bz_at_FreeBSD.org>
Date: Sat, 15 Jan 2022 22:32:36 UTC
The branch main has been updated by bz:

URL: https://cgit.FreeBSD.org/src/commit/?id=f3229b62a14953f0e487e8b32fef14b073da2890

commit f3229b62a14953f0e487e8b32fef14b073da2890
Author:     Bjoern A. Zeeb <bz@FreeBSD.org>
AuthorDate: 2022-01-15 22:18:58 +0000
Commit:     Bjoern A. Zeeb <bz@FreeBSD.org>
CommitDate: 2022-01-15 22:18:58 +0000

    LinuxKPI: 802.11 handle connection loss differently
    
    Rather than just bouncing back to SCAN bounce to INIT on connection
    loss.  This is should be refined in the future as the comment already
    indicates but we need to tie two different worlds together.
    
    Sponsored by:   The FreeBSD Foundation
    MFC after:      3 days
---
 sys/compat/linuxkpi/common/src/linux_80211.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sys/compat/linuxkpi/common/src/linux_80211.c b/sys/compat/linuxkpi/common/src/linux_80211.c
index d2e095040696..8eabf63d43d7 100644
--- a/sys/compat/linuxkpi/common/src/linux_80211.c
+++ b/sys/compat/linuxkpi/common/src/linux_80211.c
@@ -3589,11 +3589,11 @@ linuxkpi_ieee80211_connection_loss(struct ieee80211_vif *vif)
 	vap = LVIF_TO_VAP(lvif);
 
 	/*
 	 * Go to scan; otherwise we need to elaborately check state and
 	 * handle accordingly, e.g., if in RUN we could call iv_bmiss.
 	 * Let the statemachine handle all neccessary changes.
 	 */
-	nstate = IEEE80211_S_SCAN;
+	nstate = IEEE80211_S_INIT;
 	arg = 0;
 
 	if (debug_80211 & D80211_TRACE)
@@ -3589,11 +3589,11 @@ linuxkpi_ieee80211_connection_loss(struct ieee80211_vif *vif)
 
 	/*
-	 * Go to scan; otherwise we need to elaborately check state and
+	 * Go to init; otherwise we need to elaborately check state and
 	 * handle accordingly, e.g., if in RUN we could call iv_bmiss.
 	 * Let the statemachine handle all neccessary changes.